package util

import (
	"encoding/csv"
	"fmt"
	"os"
)

// DataPoint 结构体用于存储解析后的数据点，所有字段都是字符串类型
type DataPoint struct {
	Timestamp string
	X         string
	Y         string
	Z         string
	H         string
}

// ParseCsv 解析CSV文件并返回DataPoint切片
func ParseCsv(csvPath string) ([]DataPoint, error) {
	var dataPoints []DataPoint

	csvFile, err := os.Open(csvPath)
	if err != nil {
		return nil, fmt.Errorf("无法打开文件: %v", err)
	}
	defer csvFile.Close()

	reader := csv.NewReader(csvFile)

	// 读取文件的头部（列名），这里我们不需要使用它们，但可以检查以确保格式正确
	_, err = reader.Read()
	if err != nil {
		return nil, fmt.Errorf("无法读取头部: %v", err)
	}
	// 打印或检查头部（可选）
	// fmt.Println("Headers:", headers)

	// 读取文件的内容
	records, err := reader.ReadAll()
	if err != nil {
		return nil, fmt.Errorf("无法读取所有记录: %v", err)
	}

	// 处理每一行记录
	for _, record := range records {
		// 直接将读取的字符串值赋给DataPoint结构体的相应字段
		dataPoint := DataPoint{
			Timestamp: record[0],
			X:         record[1],
			Y:         record[2],
			Z:         record[3],
			H:         record[4],
		}

		// 将解析后的数据添加到切片中
		dataPoints = append(dataPoints, dataPoint)
	}

	return dataPoints, nil
}
